==> better-admin-ui-vue-0.0.1.tgz: package/es/components/Select/Select.js <==
import * as _vue from "vue";

/**
 * @Date: 2020/11/23 6:48 下午
 * @Author: Fioanna
 * @Description: 单选下拉选择器
 */
import ASelect from 'ant-design-vue/es/select';
import selectProps from './types';
var ASelectOption = ASelect.Option;
export default {
  name: 'ESelect',
  components: {
    ASelect: ASelect,
    ASelectOption: ASelectOption
  },
  props: selectProps,
  data: function data() {
    return {
      // 下拉框模式
      mode: 'default',
      // 下拉选项列表,内部使用
      optionList: []
    };
  },
  watch: {
    options: function options(newVal) {
      this.setOptionList(newVal);
    }
  },
  created: function created() {
    this.setOptionList(this.options);
  },
  methods: {
    _change: function _change() {},
    // 点击某一项选择
    _select: function _select(option) {
      var value = option[this.$props.valueName];

      if (this.$props.value !== value) {
        // 选中的改变才发送事件
        var label = option[this.$props.labelName];
        this.$emit('change', value, label, option);
      }
    },
    // 是否存在默认选中值
    _judgeExistValue: function _judgeExistValue(options) {
      var _this = this;

      if (this.value) {
        var target = options.find(function (item) {
          return item[_this.valueName] === _this.value;
        });

        if (!target) {
          // 如果可选列表中不存在默认值，则清空默认选中
          this.$emit('change', undefined, undefined);
        } else {
          // 发送一个label值变更的事件给外部记录
          this.$emit('labelChange', target[this.$props.labelName]);
        }
      }
    },
    // 设置options，可供外部使用
    setOptionList: function setOptionList(list) {
      if (list && list.length > 0) {
        this.$data.optionList = list;

        this._judgeExistValue(list);
      }
    }
  },
  render: function render() {
    var _this2 = this;

    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        placeholder = _this$$props.placeholder,
        value = _this$$props.value,
        valueName = _this$$props.valueName,
        labelName = _this$$props.labelName;
    return _vue.createVNode(_vue.resolveComponent("a-select"), {
      "disabled": disabled,
      "placeholder": placeholder,
      "value": value,
      "mode": this.$data.mode,
      "onChange": this._change
    }, {
      "default": function _default() {
        return [_this2.$data.optionList.map(function (option) {
          var value = option[valueName];
          var label = option[labelName];
          return _vue.createVNode(_vue.resolveComponent("a-select-option"), {
            "disabled": option.disabled,
            "key": value,
            "value": value,
            "title": label,
            "onClick": function onClick() {
              _this2._select(option);
            }
          }, {
            "default": function _default() {
              return [label];
            }
          });
        })];
      }
    });
  }
};

==> better-admin-ui-vue-0.0.12.tgz: package/es/components/Select/Select.js <==
/**
 * @Date: 2020/11/23 6:48 下午
 * @Author: Fioanna
 * @Description: 单选下拉选择器
 */
import ASelect from 'ant-design-vue/es/select';
import selectProps from './types';
var ASelectOption = ASelect.Option;
export default {
  name: 'ESelect',
  props: selectProps,
  data: function data() {
    return {
      // 下拉框模式
      mode: 'default',
      // 下拉选项列表,内部使用
      optionList: []
    };
  },
  watch: {
    options: function options(newVal) {
      this.setOptionList(newVal);
    }
  },
  created: function created() {
    this.setOptionList(this.options);
  },
  methods: {
    _change: function _change() {},
    // 点击某一项选择
    _select: function _select(option) {
      var value = option[this.$props.valueName];

      if (this.$props.value !== value) {
        // 选中的改变才发送事件
        var label = option[this.$props.labelName];
        this.$emit('change', value, label, option);
      }
    },
    // 是否存在默认选中值
    _judgeExistValue: function _judgeExistValue(options) {
      var _this = this;

      if (this.value) {
        var target = options.find(function (item) {
          return item[_this.valueName] === _this.value;
        });

        if (!target) {
          // 如果可选列表中不存在默认值，则清空默认选中
          this.$emit('change', undefined, undefined);
        } else {
          // 发送一个label值变更的事件给外部记录
          this.$emit('labelChange', target[this.$props.labelName]);
        }
      }
    },
    // 设置options，可供外部使用
    setOptionList: function setOptionList(list) {
      if (list && list.length > 0) {
        this.$data.optionList = list;

        this._judgeExistValue(list);
      }
    }
  },
  render: function render() {
    var _this2 = this;

    var h = arguments[0];
    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        placeholder = _this$$props.placeholder,
        value = _this$$props.value,
        valueName = _this$$props.valueName,
        labelName = _this$$props.labelName;
    return h(ASelect, {
      attrs: {
        disabled: disabled,
        placeholder: placeholder,
        value: value,
        mode: this.$data.mode
      },
      on: {
        "change": this._change
      }
    }, [this.$data.optionList.map(function (option) {
      var value = option[valueName];
      var label = option[labelName];
      return h(ASelectOption, {
        attrs: {
          disabled: option.disabled,
          value: value,
          title: label
        },
        key: value,
        on: {
          "click": function click() {
            _this2._select(option);
          }
        }
      }, [label]);
    })]);
  }
};
